#
# Configuration file for using the LIBART library in GNOME applications
#
LIBART_LIBDIR="-L/usr/X11R6/lib"
LIBART_LIBS="-lart_lgpl -lm"
LIBART_INCLUDEDIR="-I/usr/X11R6/include/gnome-1.0"
MODULE_VERSION="libart-@VERSION@"
